// package: supervisor
// file: control.proto

import * as control_pb from "./control_pb";
import {grpc} from "@improbable-eng/grpc-web";

type ControlServiceExposePort = {
  readonly methodName: string;
  readonly service: typeof ControlService;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof control_pb.ExposePortRequest;
  readonly responseType: typeof control_pb.ExposePortResponse;
};

type ControlServiceCreateSSHKeyPair = {
  readonly methodName: string;
  readonly service: typeof ControlService;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof control_pb.CreateSSHKeyPairRequest;
  readonly responseType: typeof control_pb.CreateSSHKeyPairResponse;
};

type ControlServiceCreateDebugEnv = {
  readonly methodName: string;
  readonly service: typeof ControlService;
  readonly requestStream: false;
  readonly responseStream: false;
  readonly requestType: typeof control_pb.CreateDebugEnvRequest;
  readonly responseType: typeof control_pb.CreateDebugEnvResponse;
};

export class ControlService {
  static readonly serviceName: string;
  static readonly ExposePort: ControlServiceExposePort;
  static readonly CreateSSHKeyPair: ControlServiceCreateSSHKeyPair;
  static readonly CreateDebugEnv: ControlServiceCreateDebugEnv;
}

export type ServiceError = { message: string, code: number; metadata: grpc.Metadata }
export type Status = { details: string, code: number; metadata: grpc.Metadata }

interface UnaryResponse {
  cancel(): void;
}
interface ResponseStream<T> {
  cancel(): void;
  on(type: 'data', handler: (message: T) => void): ResponseStream<T>;
  on(type: 'end', handler: (status?: Status) => void): ResponseStream<T>;
  on(type: 'status', handler: (status: Status) => void): ResponseStream<T>;
}
interface RequestStream<T> {
  write(message: T): RequestStream<T>;
  end(): void;
  cancel(): void;
  on(type: 'end', handler: (status?: Status) => void): RequestStream<T>;
  on(type: 'status', handler: (status: Status) => void): RequestStream<T>;
}
interface BidirectionalStream<ReqT, ResT> {
  write(message: ReqT): BidirectionalStream<ReqT, ResT>;
  end(): void;
  cancel(): void;
  on(type: 'data', handler: (message: ResT) => void): BidirectionalStream<ReqT, ResT>;
  on(type: 'end', handler: (status?: Status) => void): BidirectionalStream<ReqT, ResT>;
  on(type: 'status', handler: (status: Status) => void): BidirectionalStream<ReqT, ResT>;
}

export class ControlServiceClient {
  readonly serviceHost: string;

  constructor(serviceHost: string, options?: grpc.RpcOptions);
  exposePort(
    requestMessage: control_pb.ExposePortRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: control_pb.ExposePortResponse|null) => void
  ): UnaryResponse;
  exposePort(
    requestMessage: control_pb.ExposePortRequest,
    callback: (error: ServiceError|null, responseMessage: control_pb.ExposePortResponse|null) => void
  ): UnaryResponse;
  createSSHKeyPair(
    requestMessage: control_pb.CreateSSHKeyPairRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: control_pb.CreateSSHKeyPairResponse|null) => void
  ): UnaryResponse;
  createSSHKeyPair(
    requestMessage: control_pb.CreateSSHKeyPairRequest,
    callback: (error: ServiceError|null, responseMessage: control_pb.CreateSSHKeyPairResponse|null) => void
  ): UnaryResponse;
  createDebugEnv(
    requestMessage: control_pb.CreateDebugEnvRequest,
    metadata: grpc.Metadata,
    callback: (error: ServiceError|null, responseMessage: control_pb.CreateDebugEnvResponse|null) => void
  ): UnaryResponse;
  createDebugEnv(
    requestMessage: control_pb.CreateDebugEnvRequest,
    callback: (error: ServiceError|null, responseMessage: control_pb.CreateDebugEnvResponse|null) => void
  ): UnaryResponse;
}

