// package: supervisor
// file: port.proto

var port_pb = require("./port_pb");
var grpc = require("@improbable-eng/grpc-web").grpc;

var PortService = (function () {
  function PortService() {}
  PortService.serviceName = "supervisor.PortService";
  return PortService;
}());

PortService.Tunnel = {
  methodName: "Tunnel",
  service: PortService,
  requestStream: false,
  responseStream: false,
  requestType: port_pb.TunnelPortRequest,
  responseType: port_pb.TunnelPortResponse
};

PortService.CloseTunnel = {
  methodName: "CloseTunnel",
  service: PortService,
  requestStream: false,
  responseStream: false,
  requestType: port_pb.CloseTunnelRequest,
  responseType: port_pb.CloseTunnelResponse
};

PortService.EstablishTunnel = {
  methodName: "EstablishTunnel",
  service: PortService,
  requestStream: true,
  responseStream: true,
  requestType: port_pb.EstablishTunnelRequest,
  responseType: port_pb.EstablishTunnelResponse
};

PortService.AutoTunnel = {
  methodName: "AutoTunnel",
  service: PortService,
  requestStream: false,
  responseStream: false,
  requestType: port_pb.AutoTunnelRequest,
  responseType: port_pb.AutoTunnelResponse
};

PortService.RetryAutoExpose = {
  methodName: "RetryAutoExpose",
  service: PortService,
  requestStream: false,
  responseStream: false,
  requestType: port_pb.RetryAutoExposeRequest,
  responseType: port_pb.RetryAutoExposeResponse
};

exports.PortService = PortService;

function PortServiceClient(serviceHost, options) {
  this.serviceHost = serviceHost;
  this.options = options || {};
}

PortServiceClient.prototype.tunnel = function tunnel(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(PortService.Tunnel, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

PortServiceClient.prototype.closeTunnel = function closeTunnel(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(PortService.CloseTunnel, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

PortServiceClient.prototype.establishTunnel = function establishTunnel(metadata) {
  var listeners = {
    data: [],
    end: [],
    status: []
  };
  var client = grpc.client(PortService.EstablishTunnel, {
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport
  });
  client.onEnd(function (status, statusMessage, trailers) {
    listeners.status.forEach(function (handler) {
      handler({ code: status, details: statusMessage, metadata: trailers });
    });
    listeners.end.forEach(function (handler) {
      handler({ code: status, details: statusMessage, metadata: trailers });
    });
    listeners = null;
  });
  client.onMessage(function (message) {
    listeners.data.forEach(function (handler) {
      handler(message);
    })
  });
  client.start(metadata);
  return {
    on: function (type, handler) {
      listeners[type].push(handler);
      return this;
    },
    write: function (requestMessage) {
      client.send(requestMessage);
      return this;
    },
    end: function () {
      client.finishSend();
    },
    cancel: function () {
      listeners = null;
      client.close();
    }
  };
};

PortServiceClient.prototype.autoTunnel = function autoTunnel(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(PortService.AutoTunnel, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

PortServiceClient.prototype.retryAutoExpose = function retryAutoExpose(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(PortService.RetryAutoExpose, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

exports.PortServiceClient = PortServiceClient;

