// package: supervisor
// file: terminal.proto

var terminal_pb = require("./terminal_pb");
var grpc = require("@improbable-eng/grpc-web").grpc;

var TerminalService = (function () {
  function TerminalService() {}
  TerminalService.serviceName = "supervisor.TerminalService";
  return TerminalService;
}());

TerminalService.Open = {
  methodName: "Open",
  service: TerminalService,
  requestStream: false,
  responseStream: false,
  requestType: terminal_pb.OpenTerminalRequest,
  responseType: terminal_pb.OpenTerminalResponse
};

TerminalService.Shutdown = {
  methodName: "Shutdown",
  service: TerminalService,
  requestStream: false,
  responseStream: false,
  requestType: terminal_pb.ShutdownTerminalRequest,
  responseType: terminal_pb.ShutdownTerminalResponse
};

TerminalService.Get = {
  methodName: "Get",
  service: TerminalService,
  requestStream: false,
  responseStream: false,
  requestType: terminal_pb.GetTerminalRequest,
  responseType: terminal_pb.Terminal
};

TerminalService.List = {
  methodName: "List",
  service: TerminalService,
  requestStream: false,
  responseStream: false,
  requestType: terminal_pb.ListTerminalsRequest,
  responseType: terminal_pb.ListTerminalsResponse
};

TerminalService.Listen = {
  methodName: "Listen",
  service: TerminalService,
  requestStream: false,
  responseStream: true,
  requestType: terminal_pb.ListenTerminalRequest,
  responseType: terminal_pb.ListenTerminalResponse
};

TerminalService.Write = {
  methodName: "Write",
  service: TerminalService,
  requestStream: false,
  responseStream: false,
  requestType: terminal_pb.WriteTerminalRequest,
  responseType: terminal_pb.WriteTerminalResponse
};

TerminalService.SetSize = {
  methodName: "SetSize",
  service: TerminalService,
  requestStream: false,
  responseStream: false,
  requestType: terminal_pb.SetTerminalSizeRequest,
  responseType: terminal_pb.SetTerminalSizeResponse
};

TerminalService.SetTitle = {
  methodName: "SetTitle",
  service: TerminalService,
  requestStream: false,
  responseStream: false,
  requestType: terminal_pb.SetTerminalTitleRequest,
  responseType: terminal_pb.SetTerminalTitleResponse
};

TerminalService.UpdateAnnotations = {
  methodName: "UpdateAnnotations",
  service: TerminalService,
  requestStream: false,
  responseStream: false,
  requestType: terminal_pb.UpdateTerminalAnnotationsRequest,
  responseType: terminal_pb.UpdateTerminalAnnotationsResponse
};

exports.TerminalService = TerminalService;

function TerminalServiceClient(serviceHost, options) {
  this.serviceHost = serviceHost;
  this.options = options || {};
}

TerminalServiceClient.prototype.open = function open(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(TerminalService.Open, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

TerminalServiceClient.prototype.shutdown = function shutdown(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(TerminalService.Shutdown, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

TerminalServiceClient.prototype.get = function get(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(TerminalService.Get, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

TerminalServiceClient.prototype.list = function list(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(TerminalService.List, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

TerminalServiceClient.prototype.listen = function listen(requestMessage, metadata) {
  var listeners = {
    data: [],
    end: [],
    status: []
  };
  var client = grpc.invoke(TerminalService.Listen, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onMessage: function (responseMessage) {
      listeners.data.forEach(function (handler) {
        handler(responseMessage);
      });
    },
    onEnd: function (status, statusMessage, trailers) {
      listeners.status.forEach(function (handler) {
        handler({ code: status, details: statusMessage, metadata: trailers });
      });
      listeners.end.forEach(function (handler) {
        handler({ code: status, details: statusMessage, metadata: trailers });
      });
      listeners = null;
    }
  });
  return {
    on: function (type, handler) {
      listeners[type].push(handler);
      return this;
    },
    cancel: function () {
      listeners = null;
      client.close();
    }
  };
};

TerminalServiceClient.prototype.write = function write(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(TerminalService.Write, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

TerminalServiceClient.prototype.setSize = function setSize(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(TerminalService.SetSize, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

TerminalServiceClient.prototype.setTitle = function setTitle(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(TerminalService.SetTitle, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

TerminalServiceClient.prototype.updateAnnotations = function updateAnnotations(requestMessage, metadata, callback) {
  if (arguments.length === 2) {
    callback = arguments[1];
  }
  var client = grpc.unary(TerminalService.UpdateAnnotations, {
    request: requestMessage,
    host: this.serviceHost,
    metadata: metadata,
    transport: this.options.transport,
    debug: this.options.debug,
    onEnd: function (response) {
      if (callback) {
        if (response.status !== grpc.Code.OK) {
          var err = new Error(response.statusMessage);
          err.code = response.status;
          err.metadata = response.trailers;
          callback(err, null);
        } else {
          callback(null, response.message);
        }
      }
    }
  });
  return {
    cancel: function () {
      callback = null;
      client.close();
    }
  };
};

exports.TerminalServiceClient = TerminalServiceClient;

